@@ -5,11 +5,8 @@ from snowflake.sqlalchemy import URL
 from sqlalchemy import create_engine
 import logging
 logger = logging.getLogger('snowflake.connector',)
-logger.setLevel(logging.DEBUG)
-ch = logging.FileHandler('python_connector.log')
-ch.setLevel(logging.DEBUG)
-ch.setFormatter(logging.Formatter('%(asctime)s - %(threadName)s %(filename)s:%(lineno)d - %(funcName)s() - %(levelname)s - %(message)s'))
-logger.addHandler(ch)
+logger.setLevel(logging.CRITICAL)
+
 
 
 # !conda install -y -c conda-forge pyarrow
