@@ -1,7 +1,6 @@
 import streamlit as st
 from dash import MultiApp
-from apps import summary, orders, customers,traffic  # import your app modules here
-from toolkit_w.tellme import Tellme
+from apps import summary, orders, customers,traffic,discounts # import your app modules here
 
 app = MultiApp()
 
@@ -10,5 +9,6 @@ app.add_app("Summary stats", summary.app)
 app.add_app("Orders data analysis", orders.app)
 app.add_app("Customers data analysis", customers.app)
 app.add_app('Paid traffic analysis', traffic.app)
+app.add_app('Discount Analysis', discounts.app)
 # The main app
 app.run()
\ No newline at end of file
